==> rutorrent-3.9.tar.gz: ruTorrent-3.9/plugins/rss/lang/es.js <==
﻿/*
 * PLUGIN RSS
 *
 * Spanish language file.
 *
 * Author: 
 */

 theUILang.addRSS			= "Agregar RSS Feed";
 theUILang.feedURL			= "Feed URL";
 theUILang.alias			= "Alias";
 theUILang.rssAuto			= "Descargar automaticamente items publicados en este feed";
 theUILang.allFeeds			= "Todos los Feeds";
 theUILang.incorrectURL 		= "Por favor, especifique la URL correctamente."
 theUILang.cantFetchRSS 		= "Error al cargar feed.";
 theUILang.rssAlreadyExist		= "El Feed ya existe.";
 theUILang.rssDontExist 		= "El Feed no existe.";
 theUILang.rssCantLoadTorrent		= "Error al cargar torrent.";
 theUILang.rssStatus			= "RSS";
 theUILang.rssStatusLoaded		= "Ya ha sido cargado";
 theUILang.rssMenuLoad			= "Cargar";
 theUILang.rssMenuOpen			= "Abrir en navegador";
 theUILang.rssMenuClearHistory		= "Borrar Historial";
 theUILang.rssMenuAddToFilter		= "Agregar a Favoritos";
 theUILang.rssMenuManager		= "RSS Manager";
 theUILang.rssMenuRefresh		= "Actualizar Feed";
 theUILang.rssMenuDisable		= "Deshabilitar Feed";
 theUILang.rssMenuEnable		= "Habilitar Feed";
 theUILang.rssMenuEdit			= "Editar Feed";
 theUILang.rssMenuDelete		= "Borrar Feed";
 theUILang.rssDeletePrompt		= "Realmente desea borrar el feed seleccionado?";
 theUILang.rssNewFilter 		= "Nuevo filtro";
 theUILang.rssFilter			= "Filtro";
 theUILang.rssAddFilter 		= "Agregar";
 theUILang.rssDelFilter 		= "Borrar";
 theUILang.rssCheckFilter		= "?";
 theUILang.rssFiltersLegend		= "Configuracion de filtros";
 theUILang.rssIncorrectFilter		= "El filtro es incorrecto.";
 theUILang.foundedByFilter		= "Coincidencias";
 theUILang.rssExclude			= "Excluir";
 theUILang.rssStatusError		= "Error de carga";
 theUILang.rssFeeds			= "Feeds";
 theUILang.rssCheckTitle		= "Chequear titulo";
 theUILang.rssCheckDescription		= "Chequear descripcion";
 theUILang.rssCheckLink 		= "Chequear enlace";
 theUILang.rssMinInterval		= "Intervalo en Min(s)";
 theUILang.rssIntervalAlways		= "(coincide siempre)";
 theUILang.rssIntervalOnce		= "(coincide solo una vez)";
 theUILang.rssInterval12h		= "12 horas";
 theUILang.rssInterval1d		= "1 dia";
 theUILang.rssInterval2d		= "2 dias";
 theUILang.rssInterval3d		= "3 dias";
 theUILang.rssInterval4d		= "4 dias";
 theUILang.rssInterval6d		= "6 dias";
 theUILang.rssInterval1w		= "1 semana";
 theUILang.rssInterval2w		= "2 semanas";
 theUILang.rssInterval3w		= "3 semanas";
 theUILang.rssInterval1m		= "1 mes";
 theUILang.rssClearFilter		= "Reiniciar";
 theUILang.rssMarkAs			= "Marcar como";
 theUILang.rssAsLoaded			= "cargado";
 theUILang.rssAsUnloaded		= "no cargado";
 theUILang.addRSSGroup			= "Agregar grupo RSS";
 theUILang.editRSSGroup 		= "Editar grupo RSS";
 theUILang.addRSSGroupContent		= "Contenido";
 theUILang.rssMenuGroupDisable		= "Deshabilitar Grupo";
 theUILang.rssMenuGroupRefresh		= "Actualizar Grupo";
 theUILang.rssMenuGroupEnable		= "Habilitar Grupo";
 theUILang.rssMenuGroupEdit		= "Editar Grupo";
 theUILang.rssMenuGroupDelete		= "Borrar Grupo";
 theUILang.rssMenuGroupContentsDelete	= "borrar contenido";
 theUILang.rssDeleteGroupPrompt 	= "Realmente desea borrar el grupo seleccionado?";
 theUILang.rssDeleteGroupContentsPrompt = "Realmente desea borrar el grupo seleccionad con todo su contenido?";
 theUILang.rssAllFiters 		= "Todos los filtros";
 theUILang.rssUpdateInterval 		= "Update interval";
 theUILang.Directories			= "Directories";
 theUILang.Labels			= "Labels";

thePlugins.get("rss").langLoaded();

==> rutorrent-5.2.9.tar.gz: ruTorrent-5.2.9/plugins/rss/lang/es.js <==
﻿/*
 * PLUGIN RSS
 *
 * Spanish language file.
 *
 * Author: 
 */

 theUILang.addRSS			= "Agregar RSS Feed";
 theUILang.feedURL			= "Feed URL";
 theUILang.alias			= "Alias";
 theUILang.rssAuto			= "Descargar automaticamente items publicados en este feed";
 theUILang.allFeeds			= "Todos los Feeds";
 theUILang.incorrectURL			= "Por favor, especifique la URL correctamente.";
 theUILang.cantFetchRSS			= "Error al cargar feed.";
 theUILang.rssAlreadyExist		= "El Feed ya existe.";
 theUILang.rssDontExist			= "El Feed no existe.";
 theUILang.rssCantLoadTorrent		= "Error al cargar torrent.";
 theUILang.rssStatus			= "RSS";
 theUILang.rssStatusLoaded		= "Ya ha sido cargado";
 theUILang.rssMenuLoad			= "Cargar";
 theUILang.rssMenuOpen			= "Abrir en navegador";
 theUILang.rssMenuClearHistory		= "Borrar Historial";
 theUILang.rssMenuAddToFilter		= "Agregar a Favoritos";
 theUILang.rssMenuManager		= "RSS Manager";
 theUILang.rssMenuRefresh		= "Actualizar Feed";
 theUILang.rssMenuDisable		= "Deshabilitar Feed";
 theUILang.rssMenuEnable		= "Habilitar Feed";
 theUILang.rssMenuEdit			= "Editar Feed";
 theUILang.rssMenuDelete		= "Borrar Feed";
 theUILang.rssDeletePrompt		= "Realmente desea borrar el feed seleccionado?";
 theUILang.rssNewFilter			= "Nuevo filtro";
 theUILang.rssFilter			= "Filtro";
 theUILang.rssAddFilter			= "Agregar";
 theUILang.rssDelFilter			= "Borrar";
 theUILang.rssCheckFilter		= "?";
 theUILang.rssFiltersLegend		= "Configuracion de filtros";
 theUILang.rssIncorrectFilter		= "El filtro es incorrecto.";
 theUILang.foundedByFilter		= "Coincidencias";
 theUILang.rssExclude			= "Excluir";
 theUILang.rssStatusError		= "Error de carga";
 theUILang.rssFeeds			= "Feeds";
 theUILang.rssCheckTitle		= "Chequear titulo";
 theUILang.rssCheckDescription		= "Chequear descripcion";
 theUILang.rssCheckLink			= "Chequear enlace";
 theUILang.rssMinInterval		= "Intervalo en Min(s)";
 theUILang.rssIntervalAlways		= "(coincide siempre)";
 theUILang.rssIntervalOnce		= "(coincide solo una vez)";
 theUILang.rssInterval12h		= "12 horas";
 theUILang.rssInterval1d		= "1 dia";
 theUILang.rssInterval2d		= "2 dias";
 theUILang.rssInterval3d		= "3 dias";
 theUILang.rssInterval4d		= "4 dias";
 theUILang.rssInterval6d		= "6 dias";
 theUILang.rssInterval1w		= "1 semana";
 theUILang.rssInterval2w		= "2 semanas";
 theUILang.rssInterval3w		= "3 semanas";
 theUILang.rssInterval1m		= "1 mes";
 theUILang.rssClearFilter		= "Reiniciar";
 theUILang.rssMarkAs			= "Marcar como";
 theUILang.rssAsLoaded			= "cargado";
 theUILang.rssAsUnloaded		= "no cargado";
 theUILang.addRSSGroup			= "Agregar grupo RSS";
 theUILang.editRSSGroup			= "Editar grupo RSS";
 theUILang.addRSSGroupContent		= "Contenido";
 theUILang.rssMenuGroupDisable		= "Deshabilitar Grupo";
 theUILang.rssMenuGroupRefresh		= "Actualizar Grupo";
 theUILang.rssMenuGroupEnable		= "Habilitar Grupo";
 theUILang.rssMenuGroupEdit		= "Editar Grupo";
 theUILang.rssMenuGroupDelete		= "Borrar Grupo";
 theUILang.rssMenuGroupContentsDelete	= "borrar contenido";
 theUILang.rssDeleteGroupPrompt		= "Realmente desea borrar el grupo seleccionado?";
 theUILang.rssDeleteGroupContentsPrompt	= "Realmente desea borrar el grupo seleccionad con todo su contenido?";
 theUILang.rssAllFiters			= "Todos los filtros";
 theUILang.rssUpdateInterval		= "Update interval";
 theUILang.rssShowErrorsDelayed		= "Delay RSS error notification until the log tab or RSS feed is visible";
 theUILang.Directories			= "Directories";
 theUILang.Labels			= "Labels";
 theUILang.rssPatternExample		= "Regular Expression Example";

thePlugins.get("rss").langLoaded();
